EXPORTS
	?MsgTable@LoclLanguage@@SAPBQBGXZ @ 1 NONAME ; unsigned short const * const * LoclLanguage::MsgTable(void)
	?LanguageDowngrade@LoclLanguage@@SAPBW4TLanguage@@XZ @ 2 NONAME ; enum TLanguage const * LoclLanguage::LanguageDowngrade(void)
	?AmPmTable@LoclLanguage@@SAPBQBGXZ @ 3 NONAME ; unsigned short const * const * LoclLanguage::AmPmTable(void)
	?DateSuffixTable@LoclLanguage@@SAPBQBGXZ @ 4 NONAME ; unsigned short const * const * LoclLanguage::DateSuffixTable(void)
	?MonthAbbTable@LoclLanguage@@SAPBQBGXZ @ 5 NONAME ; unsigned short const * const * LoclLanguage::MonthAbbTable(void)
	?Language@LoclLanguage@@SA?AW4TLanguage@@XZ @ 6 NONAME ; enum TLanguage LoclLanguage::Language(void)
	?FatUtilityFunctions@LoclLanguage@@SAPBUTFatUtilityFunctions@@XZ @ 7 NONAME ; struct TFatUtilityFunctions const * LoclLanguage::FatUtilityFunctions(void)
	?DigitType@LoclLanguage@@SA?AW4TDigitType@@XZ @ 8 NONAME ; enum TDigitType LoclLanguage::DigitType(void)
	?MonthTable@LoclLanguage@@SAPBQBGXZ @ 9 NONAME ; unsigned short const * const * LoclLanguage::MonthTable(void)
	?DayTable@LoclLanguage@@SAPBQBGXZ @ 10 NONAME ; unsigned short const * const * LoclLanguage::DayTable(void)
	?DayAbbTable@LoclLanguage@@SAPBQBGXZ @ 11 NONAME ; unsigned short const * const * LoclLanguage::DayAbbTable(void)

